#[non_exhaustive]pub enum Source {
Memory,
File(PathBuf),
Sync(SyncOptions),
Remote(RemoteOptions),
}Expand description
Where the database lives.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Memory
A private in-memory database shared by every connection of the pool.
File(PathBuf)
A local database file, created if missing.
Sync(SyncOptions)
Available on crate feature
sync only.A local file kept in sync with a Turso Cloud database — an embedded replica.
Remote(RemoteOptions)
Available on crate feature
serverless only.A Turso Cloud database reached over HTTP, with no local file.