pub struct SyncOptions {
pub path: PathBuf,
pub remote_url: String,
pub auth_token: Option<String>,
pub bootstrap_if_empty: bool,
}Available on crate feature
sync only.Expand description
The settings of an embedded replica synchronised with Turso Cloud.
Fields
path: PathBufThe local replica file.
remote_url: StringThe remote database URL (libsql://, turso:// or https://).
auth_token: Option<String>The bearer token for the remote database.
bootstrap_if_empty: boolWhether to download the remote database on first open when the local file is empty.